#!/bin/sh
# -cr-beg-
# #############################################################################
#   Licensed Materials - Property of IBM
#
#   "Restricted Materials of IBM"
#
#   5724-U38, 5724-U39, 5724-U48, 5655-V17, 5655-V19, 5655-V35, 5655-V37
#
#   (C) Copyright IBM Corp. 2011, 2016 All Rights Reserved
#
#   (C) Copyright 2016 UNICOM (R) Systems, Inc. - All Rights Reserved
#
#   US Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with
#   IBM Corp.
# #############################################################################
# -cr-end-
# This script creates symbolic links for the ODPP and ICU libraries used by ODPP
# Usage: 
# sh createODPPsymboliclinks.sh <path> <major version> <full version>
# <path> - This is the path to the folder containing the ODPP binaries.
#
# On SUN run the script as follows: 
# /usr/xpg4/bin/sh createODPPsymboliclinks.sh <path> <major version> <full version>
#

if [ "$1" = "" ]
then
   echo "The 1st argument to the script must be the folder containing the ODPP binaries."
   exit 1
fi
if [ "$2" = "" ]
then
   echo "The 2nd argument to the script must be the major version (e.g. 11.3)."
   exit 1
fi
if [ "$3" = "" ]
then
   echo "The 3rd argument to the script must be the full version (e.g. 11.3.0.5)."
   exit 1
fi

majorver=$2
fullversion=$3

platform=`uname -s`
_MAJOR_RELEASE=`uname -a`

echo "Detecting OS..."
case ${platform} in
    AIX)
        _OS="AIX"
        _DISTRO="IBM"
        soname="a"
        _ARCH=`uname -p`
        platform_version=`uname -v`
        platform_level=`uname -r`
        _MAJOR_RELEASE="${platform_version}.${platform_level}"
        ;;

    HP-UX)
        _OS="HP-UX"
        _DISTRO="HP"
        platform_version=`uname -m`
        _MAJOR_RELEASE=`uname -r`
        if [ "$platform_version" = "ia64" ]; then
            soname="so"
            _ARCH="ia64"
        else
            soname="sl"
            _ARCH="PA-RISC"
        fi
        ;;

    Linux)
        _OS="Linux"
        _ARCH=`uname -p`
        soname="so"
        if [ -f /etc/redhat-release ] ; then
            _DISTRO="RedHat"
            _OS_VERSION=`cat /proc/version`

            # Test if this is CentOS
            _TEMP_OS=`cat /etc/redhat-release | grep 'CentOS'`
            # If this is a CentOS, RC = 0
            _RC_CENTOS=$?
            # Test if this is some other RedHat Linux
            _TEMP_OS=`cat /etc/redhat-release | grep 'Hat'`
            # If this is Red Hat, RC = 0
            _RC_REDHAT=$?
            # Test if this is RedHat Enterprise Linux
            _TEMP_OS=`cat /etc/redhat-release | grep 'Hat Enterprise'`
            # If this is Red Hat Enterprise, RC = 0
            _RC_RHEL=$?
            _TEMP_OS=`cat /etc/issue.net | head -1 | grep 'Oracle'`
            # If this is Oracle Enterprise Linux, RC = 0
            _RC_OEL=$?
            # If this is OEL, RC = 0
    
            _TEMP_OS=`uname -p | grep 's390x'`
            # If this is 64 bit zLinux, RC = 0
            _RC_S390X=$?
            # If this is zLinux 64bit, RC = 0
            _TEMP_OS=`uname -p | grep 's390'`
            # If this is 64 bit zLinux, RC = 0
            _RC_S390=$?
            # If this is zLinux 31bit, RC = 0
    
            if [ "$_RC_CENTOS" = "0" ] ; then
               _DISTRO_NAME="CentOS Linux"
            elif [ "$_RC_S390X" = "0" ] ; then
               _DISTRO_NAME="IBM zLinux s390x"
            elif [ "$_RC_S390" = "0" ] ; then
               _DISTRO_NAME="IBM zLinux s390"
            elif [ "$_RC_OEL" = "0" ] ; then
               _DISTRO_NAME="Oracle Enterprise Linux"
            elif [ "$_RC_RHEL" = "0" ] ; then
               _DISTRO_NAME="Red Hat Enterprise Linux"
            elif [ "$_RC_REDHAT" = "0" ] ; then
               _DISTRO_NAME="Red Hat Linux"
            else
               _DISTRO_NAME="Red Hat (variant) Linux"
            fi
    
            if grep -q -i "release 4" /etc/redhat-release ; then
               _MAJOR_RELEASE=4
            elif grep -q -i "release 5" /etc/redhat-release ; then
               _MAJOR_RELEASE=5
            elif grep -q -i "release 6" /etc/redhat-release ; then
               _MAJOR_RELEASE=6
            elif grep -q -i "release 7" /etc/redhat-release ; then
               _MAJOR_RELEASE=7
            elif grep -q -i "release 8" /etc/redhat-release ; then
               _MAJOR_RELEASE=8
            elif grep -q -i "release 9" /etc/redhat-release ; then
               _MAJOR_RELEASE=9
            fi
         elif [ -f /etc/SuSE-release ] ; then
            if [ "${_ARCH}" = "s390" -o "${_ARCH}" = "s390x" ]; then
                _DISTRO="IBM z/SuSE"
            else 
                _DISTRO="SuSE"
                _DISTRO_NAME="Novell SuSE Linux"
            fi
         elif [ -f /etc/mandrake-release ] ; then
            _DISTRO='Mandrake'
            _DISTRO_NAME="Mandrake Linux"
         elif [ -f /etc/debian_version ] ; then
            _DISTRO="Debian"
            _OS_VERSION=`cat /etc/debian_version`
            _MAJOR_RELEASE=$(lsb_release -rs | cut -f1 -d.)
    
             # Test if this is an Ubuntu OS
            _TEMP_OS=`lsb_release -a`
            $(grep -q "Ubuntu" <<< "${_TEMP_OS}")
            # If this is a Ubuntu OS, RC = 0
            _RC_UBUNTU=$?
            # Test if this is an Debian OS
            $(grep -q "Debian" <<< "${_TEMP_OS}")
            # If this is a Debian OS, RC = 0
            _RC_DEBIAN=$?
            if [ "$_RC_UBUNTU" = "0" ] ; then
               _DISTRO_NAME="Ubuntu Linux"
            elif [ "$_RC_DEBIAN" = "0" ] ; then
               _DISTRO_NAME="Debian Linux"
            else
               _DISTRO_NAME="Debian (variant) Linux"
            fi
         fi
         ;;

    SunOS)
        _OS="Solaris"
        soname="so"
        _ARCH=`uname -p`
        _MAJOR_RELEASE=`uname -r`
        _DISTRO="SUN"
     ;;
esac

echo "OS               = ${_OS}"
echo "Vendor           = ${_DISTRO}"
echo "Architecture     = ${_ARCH}"
echo "Release          = ${_MAJOR_RELEASE}"
echo "Library type     = ${soname}"
echo "Target Directory = $1"
echo "Optim version    = ${fullversion}"

#We will always remove the symbolic link if it exists
#options=$2
options=clean      
if [ "$options" = "clean" ]   
then
   echo "Deleting symbolic links and duplicates for the ODPP libraries"   
   if [ "$platform" = "AIX" ]
   then
      if [[ -L $1/libODPProvider.$majorver.${soname} || -e $1/libODPProvider.$majorver.${soname} ]]; then rm $1/libODPProvider.$majorver.${soname}; fi 
      if [[ -L $1/libODPPOSLibUnix.${soname} || -e $1/libODPPOSLibUnix.${soname} ]]; then rm $1/libODPPOSLibUnix.${soname}; fi 
      if [[ -L $1/libODPPOSLibUnix.$majorver.${soname} || -e $1/libODPPOSLibUnix.$majorver.${soname} ]]; then rm $1/libODPPOSLibUnix.$majorver.${soname}; fi 
      if [[ -L $1/libODPPEnvLib.${soname} || -e $1/libODPPEnvLib.${soname} ]]; then rm $1/libODPPEnvLib.${soname}; fi 
      if [[ -L $1/libODPPEnvLib.$majorver.${soname} || -e $1/libODPPEnvLib.$majorver.${soname} ]]; then rm $1/libODPPEnvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPPICULib.${soname} || -e $1/libODPPICULib.${soname} ]]; then rm $1/libODPPICULib.${soname}; fi 
      if [[ -L $1/libODPPICULib.$majorver.${soname} || -e $1/libODPPICULib.$majorver.${soname} ]]; then rm $1/libODPPICULib.$majorver.${soname}; fi 
      if [[ -L $1/libODPPDataCnvLib.${soname} || -e $1/libODPPDataCnvLib.${soname} ]]; then rm $1/libODPPDataCnvLib.${soname}; fi 
      if [[ -L $1/libODPPDataCnvLib.$majorver.${soname} || -e $1/libODPPDataCnvLib.$majorver.${soname} ]]; then rm $1/libODPPDataCnvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPPXMLReaderLib.${soname} || -e $1/libODPPXMLReaderLib.${soname} ]]; then rm $1/libODPPXMLReaderLib.${soname}; fi 
      if [[ -L $1/libODPPXMLReaderLib.$majorver.${soname} || -e $1/libODPPXMLReaderLib.$majorver.${soname} ]]; then rm $1/libODPPXMLReaderLib.$majorver.${soname}; fi   
      if [[ -L $1/libODPPLicl.${soname} || -e $1/libODPPLicl.${soname} ]]; then rm $1/libODPPLicl.${soname}; fi 
      if [[ -L $1/libODPPLicl.$majorver.${soname} || -e $1/libODPPLicl.$majorver.${soname} ]]; then rm $1/libODPPLicl.$majorver.${soname}; fi 
      if [[ -L $1/libODPCCNPrvLib.${soname} || -e $1/libODPCCNPrvLib.${soname} ]]; then rm $1/libODPCCNPrvLib.${soname}; fi 
      if [[ -L $1/libODPCCNPrvLib.$majorver.${soname} || -e $1/libODPCCNPrvLib.$majorver.${soname} ]]; then rm $1/libODPCCNPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPNIDPrvLib.${soname} || -e $1/libODPNIDPrvLib.${soname} ]]; then rm $1/libODPNIDPrvLib.${soname}; fi 
      if [[ -L $1/libODPNIDPrvLib.$majorver.${soname} || -e $1/libODPNIDPrvLib.$majorver.${soname} ]]; then rm $1/libODPNIDPrvLib.$majorver.${soname}; fi   
      if [[ -L $1/libODPEMLPrvLib.${soname} || -e $1/libODPEMLPrvLib.${soname} ]]; then rm $1/libODPEMLPrvLib.${soname}; fi 
      if [[ -L $1/libODPEMLPrvLib.$majorver.${soname} || -e $1/libODPEMLPrvLib.$majorver.${soname} ]]; then rm $1/libODPEMLPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPCOLPrvLib.${soname} || -e $1/libODPCOLPrvLib.${soname} ]]; then rm $1/libODPCOLPrvLib.${soname}; fi 
      if [[ -L $1/libODPCOLPrvLib.$majorver.${soname} || -e $1/libODPCOLPrvLib.$majorver.${soname} ]]; then rm $1/libODPCOLPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPHASHPrvLib.${soname} || -e $1/libODPHASHPrvLib.${soname} ]]; then rm $1/libODPHASHPrvLib.${soname}; fi 
      if [[ -L $1/libODPHASHPrvLib.$majorver.${soname} || -e $1/libODPHASHPrvLib.$majorver.${soname} ]]; then rm $1/libODPHASHPrvLib.$majorver.${soname}; fi   
      if [[ -L $1/libODPAGEPrvLib.${soname} || -e $1/libODPAGEPrvLib.${soname} ]]; then rm $1/libODPAGEPrvLib.${soname}; fi 
      if [[ -L $1/libODPAGEPrvLib.$majorver.${soname} || -e $1/libODPAGEPrvLib.$majorver.${soname} ]]; then rm $1/libODPAGEPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPPLDSDB2Lib.${soname} || -e $1/libODPPLDSDB2Lib.${soname} ]]; then rm $1/libODPPLDSDB2Lib.${soname}; fi 
      if [[ -L $1/libODPPLDSDB2Lib.$majorver.${soname} || -e $1/libODPPLDSDB2Lib.$majorver.${soname} ]]; then rm $1/libODPPLDSDB2Lib.$majorver.${soname}; fi  
      if [[ -L $1/libODPLKPPrvLib.${soname} || -e $1/libODPLKPPrvLib.${soname} ]]; then rm $1/libODPLKPPrvLib.${soname}; fi 
      if [[ -L $1/libODPLKPPrvLib.$majorver.${soname} || -e $1/libODPLKPPrvLib.$majorver.${soname} ]]; then rm $1/libODPLKPPrvLib.$majorver.${soname}; fi  
      if [[ -L $1/libODPPAdapter.${soname} || -e $1/libODPPAdapter.${soname} ]]; then rm $1/libODPPAdapter.${soname}; fi 
      if [[ -L $1/libODPPAdapter.$majorver.${soname} || -e $1/libODPPAdapter.$majorver.${soname} ]]; then rm $1/libODPPAdapter.$majorver.${soname}; fi  
      if [[ -L $1/libODPPParser.${soname} || -e $1/libODPPParser.${soname} ]]; then rm $1/libODPPParser.${soname}; fi 
      if [[ -L $1/libODPPParser.$majorver.${soname} || -e $1/libODPPParser.$majorver.${soname} ]]; then rm $1/libODPPParser.$majorver.${soname}; fi  
      if [[ -L $1/libODPPErrorHandler.${soname} || -e $1/libODPPErrorHandler.${soname} ]]; then rm $1/libODPPErrorHandler.${soname}; fi 
      if [[ -L $1/libODPPErrorHandler.$majorver.${soname} || -e $1/libODPPErrorHandler.$majorver.${soname} ]]; then rm $1/libODPPErrorHandler.$majorver.${soname}; fi  
      if [[ -L $1/libODPPInstMgr.${soname} || -e $1/libODPPInstMgr.${soname} ]]; then rm $1/libODPPInstMgr.${soname}; fi 
      if [[ -L $1/libODPPInstMgr.$majorver.${soname} || -e $1/libODPPInstMgr.$majorver.${soname} ]]; then rm $1/libODPPInstMgr.$majorver.${soname}; fi
      if [[ -L $1/libODPPConvert.${soname} || -e $1/libODPPConvert.${soname} ]]; then rm $1/libODPPConvert.${soname}; fi 
      if [[ -L $1/libODPPConvert.$majorver.${soname} || -e $1/libODPPConvert.$majorver.${soname} ]]; then rm $1/libODPPConvert.$majorver.${soname}; fi 
      if [[ -L $1/libIOQMODJNI.$majorver.${soname} || -e $1/libIOQMODJNI.$majorver.${soname} ]]; then rm $1/libIOQMODJNI.$majorver.${soname}; fi        
      if [[ -L $1/libODPDSWAPPrvLib.${soname} || -e $1/libODPDSWAPPrvLib.${soname} ]]; then rm $1/libODPDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPDSWAPPrvLib.$majorver.${soname} || -e $1/libODPDSWAPPrvLib.$majorver.${soname} ]]; then rm $1/libODPDSWAPPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPCDSWAPPrvLib.${soname} || -e $1/libODPCDSWAPPrvLib.${soname} ]]; then rm $1/libODPCDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPCDSWAPPrvLib.$majorver.${soname} || -e $1/libODPCDSWAPPrvLib.$majorver.${soname} ]]; then rm $1/libODPCDSWAPPrvLib.$majorver.${soname}; fi 
      if [[ -L $1/libODPDDSWAPPrvLib.${soname} || -e $1/libODPDDSWAPPrvLib.${soname} ]]; then rm $1/libODPDDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPDDSWAPPrvLib.$majorver.${soname} || -e $1/libODPDDSWAPPrvLib.$majorver.${soname} ]]; then rm $1/libODPDDSWAPPrvLib.$majorver.${soname}; fi
      if [[ -L $1/libODPPORAUdf.${soname} || -e $1/libODPPORAUdf.${soname} ]]; then rm $1/libODPPORAUdf.${soname}; fi 
      if [[ -L $1/libODPPORAUdf.$majorver.${soname} || -e $1/libODPPORAUdf.$majorver.${soname} ]]; then rm $1/libODPPORAUdf.$majorver.${soname}; fi
      if [[ -L $1/libioqoraudf.${soname} || -e $1/libioqoraudf.${soname} ]]; then rm $1/libioqoraudf.${soname}; fi 
      if [[ -L $1/libioqoraudf.$majorver.${soname} || -e $1/libioqoraudf.$majorver.${soname} ]]; then rm $1/libioqoraudf.$majorver.${soname}; fi
      if [[ -L $1/libioqhash.${soname} || -e $1/libioqhash.${soname} ]]; then rm $1/libioqhash.${soname}; fi 
      if [[ -L $1/libioqhash.$majorver.${soname} || -e $1/libioqhash.$majorver.${soname} ]]; then rm $1/libioqhash.$majorver.${soname}; fi
      if [[ -L $1/libODPPLoader.${soname} || -e $1/libODPPLoader.${soname} ]]; then rm $1/libODPPLoader.${soname}; fi 
      if [[ -L $1/libODPPLoader.$majorver.${soname} || -e $1/libODPPLoader.$majorver.${soname} ]]; then rm $1/libODPPLoader.$majorver.${soname}; fi
      if [[ -L $1/libioqdb2udf.${soname} || -e $1/libioqdb2udf.${soname} ]]; then rm $1/libioqdb2udf.${soname}; fi 
      if [[ -L $1/libioqldsoralib.${soname} || -e $1/libioqldsoralib.${soname} ]]; then rm $1/libioqldsoralib.${soname}; fi 
      if [[ -L $1/libioqldsoralib.$majorver.${soname} || -e $1/libioqldsoralib.$majorver.${soname} ]]; then rm $1/libioqldsoralib.$majorver.${soname}; fi
      if [[ -L $1/libioqldsoralib.${soname}.$majorver || -e $1/libioqldsoralib.${soname}.$majorver ]]; then rm $1/libioqldsoralib.${soname}.$majorver; fi
      if [[ -L $1/libioqspe.${soname} || -e $1/libioqspe.${soname} ]]; then rm $1/libioqspe.${soname}; fi 
      if [[ -L $1/libioqspe.$majorver.${soname} || -e $1/libioqspe.$majorver.${soname} ]]; then rm $1/libioqspe.$majorver.${soname}; fi
   else
      if [[ -L $1/libODPProvider.${soname}.$majorver || -e $1/libODPProvider.${soname}.$majorver ]]; then rm $1/libODPProvider.${soname}.$majorver; fi       
      #sym link for libODPProvider with major ver added for Oracle UDF
      if [[ -L $1/libODPProvider.$majorver.${soname} || -e $1/libODPProvider.$majorver.${soname} ]]; then rm $1/libODPProvider.$majorver.${soname}; fi       
      if [[ -L $1/libODPPLDSDB2Lib.${soname} || -e $1/libODPPLDSDB2Lib.${soname} ]]; then rm $1/libODPPLDSDB2Lib.${soname}; fi       
      if [[ -L $1/libODPPLDSDB2Lib.${soname}.$majorver || -e $1/libODPPLDSDB2Lib.${soname}.$majorver ]]; then rm $1/libODPPLDSDB2Lib.${soname}.$majorver; fi 
      if [[ -L $1/libODPLKPPrvLib.${soname} || -e $1/libODPLKPPrvLib.${soname} ]]; then rm $1/libODPLKPPrvLib.${soname}; fi 
      if [[ -L $1/libODPLKPPrvLib.${soname}.$majorver || -e $1/libODPLKPPrvLib.${soname}.$majorver ]]; then rm $1/libODPLKPPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPAGEPrvLib.${soname} || -e $1/libODPAGEPrvLib.${soname} ]]; then rm $1/libODPAGEPrvLib.${soname}; fi 
      if [[ -L $1/libODPAGEPrvLib.${soname}.$majorver || -e $1/libODPAGEPrvLib.${soname}.$majorver ]]; then rm $1/libODPAGEPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPHASHPrvLib.${soname} || -e $1/libODPHASHPrvLib.${soname} ]]; then rm $1/libODPHASHPrvLib.${soname}; fi       
      if [[ -L $1/libODPHASHPrvLib.${soname}.$majorver || -e $1/libODPHASHPrvLib.${soname}.$majorver ]]; then rm $1/libODPHASHPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPCOLPrvLib.${soname} || -e $1/libODPCOLPrvLib.${soname} ]]; then rm $1/libODPCOLPrvLib.${soname}; fi 
      if [[ -L $1/libODPCOLPrvLib.${soname}.$majorver || -e $1/libODPCOLPrvLib.${soname}.$majorver ]]; then rm $1/libODPCOLPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPEMLPrvLib.${soname} || -e $1/libODPEMLPrvLib.${soname} ]]; then rm $1/libODPEMLPrvLib.${soname}; fi 
      if [[ -L $1/libODPEMLPrvLib.${soname}.$majorver || -e $1/libODPEMLPrvLib.${soname}.$majorver ]]; then rm $1/libODPEMLPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPNIDPrvLib.${soname} || -e $1/libODPNIDPrvLib.${soname} ]]; then rm $1/libODPNIDPrvLib.${soname}; fi       
      if [[ -L $1/libODPNIDPrvLib.${soname}.$majorver || -e $1/libODPNIDPrvLib.${soname}.$majorver ]]; then rm $1/libODPNIDPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPCCNPrvLib.${soname} || -e $1/libODPCCNPrvLib.${soname} ]]; then rm $1/libODPCCNPrvLib.${soname}; fi 
      if [[ -L $1/libODPCCNPrvLib.${soname}.$majorver || -e $1/libODPCCNPrvLib.${soname}.$majorver ]]; then rm $1/libODPCCNPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPPLicl.${soname} || -e $1/libODPPLicl.${soname} ]]; then rm $1/libODPPLicl.${soname}; fi 
      if [[ -L $1/libODPPLicl.${soname}.$majorver || -e $1/libODPPLicl.${soname}.$majorver ]]; then rm $1/libODPPLicl.${soname}.$majorver; fi 
      if [[ -L $1/libODPPXMLReaderLib.${soname} || -e $1/libODPPXMLReaderLib.${soname} ]]; then rm $1/libODPPXMLReaderLib.${soname}; fi       
      if [[ -L $1/libODPPXMLReaderLib.${soname}.$majorver || -e $1/libODPPXMLReaderLib.${soname}.$majorver ]]; then rm $1/libODPPXMLReaderLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPDataCnvLib.${soname} || -e $1/libODPPDataCnvLib.${soname} ]]; then rm $1/libODPPDataCnvLib.${soname}; fi 
      if [[ -L $1/libODPPDataCnvLib.${soname}.$majorver || -e $1/libODPPDataCnvLib.${soname}.$majorver ]]; then rm $1/libODPPDataCnvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPICULib.${soname} || -e $1/libODPPICULib.${soname} ]]; then rm $1/libODPPICULib.${soname}; fi       
      if [[ -L $1/libODPPICULib.${soname}.$majorver || -e $1/libODPPICULib.${soname}.$majorver ]]; then rm $1/libODPPICULib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPEnvLib.${soname} || -e $1/libODPPEnvLib.${soname} ]]; then rm $1/libODPPEnvLib.${soname}; fi 
      if [[ -L $1/libODPPEnvLib.${soname}.$majorver || -e $1/libODPPEnvLib.${soname}.$majorver ]]; then rm $1/libODPPEnvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPPOSLibUnix.${soname} || -e $1/libODPPOSLibUnix.${soname} ]]; then rm $1/libODPPOSLibUnix.${soname}; fi 
      if [[ -L $1/libODPPOSLibUnix.${soname}.$majorver || -e $1/libODPPOSLibUnix.${soname}.$majorver ]]; then rm $1/libODPPOSLibUnix.${soname}.$majorver; fi     
      if [[ -L $1/libODPPAdapter.${soname} || -e $1/libODPPAdapter.${soname} ]]; then rm $1/libODPPAdapter.${soname}; fi 
      if [[ -L $1/libODPPAdapter.${soname}.$majorver || -e $1/libODPPAdapter.${soname}.$majorver ]]; then rm $1/libODPPAdapter.${soname}.$majorver; fi     
      if [[ -L $1/libODPPParser.${soname} || -e $1/libODPPParser.${soname} ]]; then rm $1/libODPPParser.${soname}; fi 
      if [[ -L $1/libODPPParser.${soname}.$majorver || -e $1/libODPPParser.${soname}.$majorver ]]; then rm $1/libODPPParser.${soname}.$majorver; fi     
      if [[ -L $1/libODPPErrorHandler.${soname} || -e $1/libODPPErrorHandler.${soname} ]]; then rm $1/libODPPErrorHandler.${soname}; fi 
      if [[ -L $1/libODPPErrorHandler.${soname}.$majorver || -e $1/libODPPErrorHandler.${soname}.$majorver ]]; then rm $1/libODPPErrorHandler.${soname}.$majorver; fi     
      if [[ -L $1/libODPPInstMgr.${soname} || -e $1/libODPPInstMgr.${soname} ]]; then rm $1/libODPPInstMgr.${soname}; fi 
      if [[ -L $1/libODPPInstMgr.${soname}.$majorver || -e $1/libODPPInstMgr.${soname}.$majorver ]]; then rm $1/libODPPInstMgr.${soname}.$majorver; fi           
      if [[ -L $1/libODPPConvert.${soname} || -e $1/libODPPConvert.${soname} ]]; then rm $1/libODPPConvert.${soname}; fi 
      if [[ -L $1/libODPPConvert.${soname}.$majorver || -e $1/libODPPConvert.${soname}.$majorver ]]; then rm $1/libODPPConvert.${soname}.$majorver; fi       
      if [[ -L $1/libODPDSWAPPrvLib.${soname} || -e $1/libODPDSWAPPrvLib.${soname} ]]; then rm $1/libODPDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPDSWAPPrvLib.${soname}.$majorver || -e $1/libODPDSWAPPrvLib.${soname}.$majorver ]]; then rm $1/libODPDSWAPPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPCDSWAPPrvLib.${soname} || -e $1/libODPCDSWAPPrvLib.${soname} ]]; then rm $1/libODPCDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPCDSWAPPrvLib.${soname}.$majorver || -e $1/libODPCDSWAPPrvLib.${soname}.$majorver ]]; then rm $1/libODPCDSWAPPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPDDSWAPPrvLib.${soname} || -e $1/libODPDDSWAPPrvLib.${soname} ]]; then rm $1/libODPDDSWAPPrvLib.${soname}; fi 
      if [[ -L $1/libODPDDSWAPPrvLib.${soname}.$majorver || -e $1/libODPDDSWAPPrvLib.${soname}.$majorver ]]; then rm $1/libODPDDSWAPPrvLib.${soname}.$majorver; fi      
      if [[ -L $1/libODPPORAUdf.${soname} || -e $1/libODPPORAUdf.${soname} ]]; then rm $1/libODPPORAUdf.${soname}; fi 
      if [[ -L $1/libODPPORAUdf.$majorver.${soname} || -e $1/libODPPORAUdf.$majorver.${soname} ]]; then rm $1/libODPPORAUdf.$majorver.${soname}; fi                      
      if [[ -L $1/libIOQMODJNI.$majorver.${soname} || -e $1/libIOQMODJNI.$majorver.${soname} ]]; then rm $1/libIOQMODJNI.$majorver.${soname}; fi    
      if [[ -L $1/libIOQMODJNI.${soname}.$majorver || -e $1/libIOQMODJNI.${soname}.$majorver ]]; then rm $1/libIOQMODJNI.${soname}.$majorver; fi 
      if [ "$platform" = "Linux" ] 
      then  
         if [[ -L $1/libODPPJNI.$majorver.${soname} || -e $1/libODPPJNI.$majorver.${soname} ]]; then rm $1/libODPPJNI.$majorver.${soname}; fi    
         if [[ -L $1/libODPPJNI.${soname}.$majorver || -e $1/libODPPJNI.${soname}.$majorver ]]; then rm $1/libODPPJNI.${soname}.$majorver; fi 
      fi              
      if [[ -L $1/libioqoraudf.${soname} || -e $1/libioqoraudf.${soname} ]]; then rm $1/libioqoraudf.${soname}; fi 
      if [[ -L $1/libioqoraudf.$majorver.${soname} || -e $1/libioqoraudf.$majorver.${soname} ]]; then rm $1/libioqoraudf.$majorver.${soname}; fi                
      if [[ -L $1/libioqoraudf.${soname}.$majorver || -e $1/libioqoraudf.${soname}.$majorver ]]; then rm $1/libioqoraudf.${soname}.$majorver; fi                
      if [[ -L $1/libioqhash.${soname} || -e $1/libioqhash.${soname} ]]; then rm $1/libioqhash.${soname}; fi 
      if [[ -L $1/libioqhash.${soname}.$majorver || -e $1/libioqhash.${soname}.$majorver ]]; then rm $1/libioqhash.${soname}.$majorver; fi           
      if [[ -L $1/libODPPLoader.${soname} || -e $1/libODPPLoader.${soname} ]]; then rm $1/libODPPLoader.${soname}; fi 
      if [[ -L $1/libODPPLoader.${soname}.$majorver || -e $1/libODPPLoader.${soname}.$majorver ]]; then rm $1/libODPPLoader.${soname}.$majorver; fi     
      if [[ -L $1/libioqldsoralib.${soname} || -e $1/libioqldsoralib.${soname} ]]; then rm $1/libioqldsoralib.${soname}; fi 
      if [[ -L $1/libioqldsoralib.${soname}.$majorver || -e $1/libioqldsoralib.${soname}.$majorver ]]; then rm $1/libioqldsoralib.${soname}.$majorver; fi
      if [[ -L $1/libioqdb2udf.${soname} || -e $1/libioqdb2udf.${soname} ]]; then rm $1/libioqdb2udf.${soname}; fi 
      if [[ -L $1/libioqdb2udf.${soname}.$majorver || -e $1/libioqdb2udf.${soname}.$majorver ]]; then rm $1/libioqdb2udf.${soname}.$majorver; fi
      if [[ -L $1/libioqspe.${soname} || -e $1/libioqspe.${soname} ]]; then rm $1/libioqspe.${soname}; fi 
      if [[ -L $1/libioqspe.${soname}.$majorver || -e $1/libioqspe.${soname}.$majorver ]]; then rm $1/libioqspe.${soname}.$majorver; fi 
   fi
fi
echo "Creating symbolic links for the ODPP libraries"
if [ "$platform" = "AIX" ]
then
   ln -s libODPProvider.$fullversion.${soname} $1/libODPProvider.$majorver.${soname}
   ln -s libODPPOSLibUnix.$fullversion.${soname} $1/libODPPOSLibUnix.$majorver.${soname}
   ln -s libODPPEnvLib.$fullversion.${soname} $1/libODPPEnvLib.$majorver.${soname}
   ln -s libODPPICULib.$fullversion.${soname} $1/libODPPICULib.$majorver.${soname}
   ln -s libODPPDataCnvLib.$fullversion.${soname} $1/libODPPDataCnvLib.$majorver.${soname}
   if [ -e $1/libODPPConvert.$fullversion.${soname} ] 
   then 
     ln -s  libODPPConvert.$fullversion.${soname} $1/libODPPConvert.$majorver.${soname}
   fi
   ln -s libODPCCNPrvLib.$fullversion.${soname} $1/libODPCCNPrvLib.$majorver.${soname}
   ln -s libODPNIDPrvLib.$fullversion.${soname} $1/libODPNIDPrvLib.$majorver.${soname}
   ln -s libODPEMLPrvLib.$fullversion.${soname} $1/libODPEMLPrvLib.$majorver.${soname}
   ln -s libODPCOLPrvLib.$fullversion.${soname} $1/libODPCOLPrvLib.$majorver.${soname}
   ln -s libODPHASHPrvLib.$fullversion.${soname} $1/libODPHASHPrvLib.$majorver.${soname}
   ln -s libODPAGEPrvLib.$fullversion.${soname} $1/libODPAGEPrvLib.$majorver.${soname}
   ln -s libODPPLDSDB2Lib.$fullversion.${soname} $1/libODPPLDSDB2Lib.$majorver.${soname}
   ln -s libODPLKPPrvLib.$fullversion.${soname} $1/libODPLKPPrvLib.$majorver.${soname}
   ln -s libODPPAdapter.$fullversion.${soname} $1/libODPPAdapter.$majorver.${soname}
   ln -s libODPPParser.$fullversion.${soname} $1/libODPPParser.$majorver.${soname}
   ln -s libODPPErrorHandler.$fullversion.${soname} $1/libODPPErrorHandler.$majorver.${soname}
   ln -s libODPPInstMgr.$fullversion.${soname} $1/libODPPInstMgr.$majorver.${soname}
   ln -s libIOQMODJNI.$fullversion.${soname} $1/libIOQMODJNI.$majorver.${soname}   
   ln -s libODPDSWAPPrvLib.$fullversion.${soname} $1/libODPDSWAPPrvLib.$majorver.${soname}
   ln -s libODPCDSWAPPrvLib.$fullversion.${soname} $1/libODPCDSWAPPrvLib.$majorver.${soname}
   ln -s libODPDDSWAPPrvLib.$fullversion.${soname} $1/libODPDDSWAPPrvLib.$majorver.${soname}    
   ln -s libioqhash.$fullversion.${soname} $1/libioqhash.$majorver.${soname}
   if [ -e $1/libioqspe.$fullversion.${soname} ]   
   then
      ln -s libioqspe.$fullversion.${soname} $1/libioqspe.$majorver.${soname}
   fi
   ln -s libioqldsoralib.$fullversion.${soname} $1/libioqldsoralib.$majorver.${soname}
   ln -s libODPPLoader.$fullversion.${soname} $1/libODPPLoader.$majorver.${soname}
   if [ -e $1/libODPPORAUdf.$fullversion.${soname} ]
   then 
      ln -s  libODPPORAUdf.$fullversion.${soname} $1/libODPPORAUdf.$majorver.${soname}
      ln -s  libODPPORAUdf.$fullversion.${soname} $1/libODPPORAUdf.${soname}
   fi
   if [ -e $1/libioqoraudf.$fullversion.${soname} ]
   then 
      ln -s  libioqoraudf.$fullversion.${soname} $1/libioqoraudf.$majorver.${soname}
      ln -s  libioqoraudf.$fullversion.${soname} $1/libioqoraudf.${soname}
   fi
   if [ -e $1/libODPProvider.${soname}.$fullversion ]
   then 
      ln -s libODPProvider.${soname}.$fullversion $1/libODPProvider.${soname}.$majorver
   fi
else
   ln -s libODPProvider.${soname}.$fullversion $1/libODPProvider.${soname}.$majorver
   ln -s libODPPOSLibUnix.${soname}.$fullversion $1/libODPPOSLibUnix.${soname}.$majorver
   ln -s libODPPEnvLib.${soname}.$fullversion $1/libODPPEnvLib.${soname}.$majorver
   ln -s libODPPICULib.${soname}.$fullversion $1/libODPPICULib.${soname}.$majorver
   ln -s libODPPDataCnvLib.${soname}.$fullversion $1/libODPPDataCnvLib.${soname}.$majorver
   ln -s libODPCCNPrvLib.${soname}.$fullversion $1/libODPCCNPrvLib.${soname}.$majorver
   ln -s libODPNIDPrvLib.${soname}.$fullversion $1/libODPNIDPrvLib.${soname}.$majorver
   ln -s libODPEMLPrvLib.${soname}.$fullversion $1/libODPEMLPrvLib.${soname}.$majorver
   ln -s libODPCOLPrvLib.${soname}.$fullversion $1/libODPCOLPrvLib.${soname}.$majorver
   ln -s libODPHASHPrvLib.${soname}.$fullversion $1/libODPHASHPrvLib.${soname}.$majorver
   ln -s libODPAGEPrvLib.${soname}.$fullversion $1/libODPAGEPrvLib.${soname}.$majorver
   ln -s libODPPLDSDB2Lib.${soname}.$fullversion $1/libODPPLDSDB2Lib.${soname}.$majorver
   ln -s libODPLKPPrvLib.${soname}.$fullversion $1/libODPLKPPrvLib.${soname}.$majorver 
   ln -s libODPPAdapter.${soname}.$fullversion $1/libODPPAdapter.${soname}.$majorver 
   ln -s libODPPParser.${soname}.$fullversion $1/libODPPParser.${soname}.$majorver 
   ln -s libODPPErrorHandler.${soname}.$fullversion $1/libODPPErrorHandler.${soname}.$majorver 
   ln -s libODPPInstMgr.${soname}.$fullversion $1/libODPPInstMgr.${soname}.$majorver    
   ln -s libODPDSWAPPrvLib.${soname}.$fullversion $1/libODPDSWAPPrvLib.${soname}.$majorver
   ln -s libODPCDSWAPPrvLib.${soname}.$fullversion $1/libODPCDSWAPPrvLib.${soname}.$majorver
   ln -s libODPDDSWAPPrvLib.${soname}.$fullversion $1/libODPDDSWAPPrvLib.${soname}.$majorver
   ln -s libioqhash.${soname}.$fullversion $1/libioqhash.${soname}.$majorver
   if [ -e $1/libioqspe.${soname}.$fullversion ]
   then
      ln -s libioqspe.${soname}.$fullversion $1/libioqspe.${soname}.$majorver
   fi
   ln -s libioqldsoralib.${soname}.$fullversion $1/libioqldsoralib.${soname}.$majorver
   ln -s libODPPLoader.${soname}.$fullversion $1/libODPPLoader.${soname}.$majorver
   if [ -e $1/libIOQMODJNI.${soname}.$fullversion ]
   then 
      ln -s  libIOQMODJNI.${soname}.$fullversion $1/libIOQMODJNI.$majorver.${soname};
      ln -s  libIOQMODJNI.${soname}.$fullversion $1/libIOQMODJNI.${soname}.$majorver;
      #remove the ODPP sym link before re-creating it
      if [[ -L $1/libODPProvider.$majorver.${soname} || -e $1/libODPProvider.$majorver.${soname} ]]; then rm $1/libODPProvider.$majorver.${soname}; fi       
      ln -s  libODPProvider.${soname}.$fullversion $1/libODPProvider.$majorver.${soname};
   fi   
   if [ "$platform" = "Linux" ] 
   then
      if [ -e $1/libODPPJNI.${soname}.$fullversion ]
      then 
         ln -s  libODPPJNI.${soname}.$fullversion $1/libODPPJNI.$majorver.${soname};
         ln -s  libODPPJNI.${soname}.$fullversion $1/libODPPJNI.${soname}.$majorver;
      fi  
   fi
   #sym link for libODPProvider with major ver added for Oracle UDF
   if [ -e $1/libODPPORAUdf.${soname}.$fullversion ]
   then 
      ln -s  libODPPORAUdf.${soname}.$fullversion $1/libODPPORAUdf.$majorver.${soname};
      [ -L $1/libODPProvider.$majorver.${soname} ] && rm $1/libODPProvider.$majorver.${soname}
      ln -s  libODPProvider.${soname}.$fullversion $1/libODPProvider.$majorver.${soname};
   fi
   if [ -e $1/libioqoraudf.${soname}.$fullversion ]
   then 
      ln -s  libioqoraudf.${soname}.$fullversion $1/libioqoraudf.${soname}.$majorver;
      ln -s  libioqoraudf.${soname}.$fullversion $1/libioqoraudf.$majorver.${soname};
   fi
   if [ -e libioqdb2udf.${soname}.$fullversion ]
   then 
      [ -L $1/libODPProvider.${soname}.$majorver ] && rm $1/libODPProvider.${soname}.$majorver
      ln -s libODPProvider.${soname}.$fullversion $1/libODPProvider.${soname}.$majorver
   fi
      
   if [ -e $1/libODPPConvert.${soname}.$fullversion ]
   then 
      ln -s  libODPPConvert.${soname}.$fullversion $1/libODPPConvert.${soname}.$majorver; 
   fi
fi


#XERCESC Symbolic Links
#Xerces - Starting with 11.3.0.4 iFix12
#We will always remove the symbolic link if it exists
#options=$2
options=clean
if [ "$options" = "clean" ]
then
   echo "Deleting symbolic links and duplicates for the XERCESC libraries"   
   if [ "$platform" != "AIX" ]
   then
      if [[ -L $1/libxerces-c.${soname} || -e $1/libxerces-c.${soname} ]]
      then 
          rm $1/libxerces-c.${soname}
      fi
   fi
fi
#ICU 4.8 Symbolic Links
  
#We will always remove the symbolic link if it exists
#options=$2
 options=clean      
 if [ "$options" = "clean" ]   
 then
     echo "Deleting symbolic links and duplicates for the ICU 48 libraries"   
     if [ "$platform" = "AIX" ]
     then
        if [[ -L $1/libicudata48.${soname} || -e $1/libicudata48.${soname} ]]; then rm $1/libicudata48.${soname}; fi
        if [[ -L $1/libicuuc48.${soname} || -e $1/libicuuc48.${soname} ]]; then rm $1/libicuuc48.${soname}; fi
        if [[ -L $1/libicudata.${soname} || -e $1/libicudata.${soname} ]]; then rm $1/libicudata.${soname}; fi 
        if [[ -L $1/libicuuc.${soname} || -e $1/libicuuc.${soname} ]]; then rm $1/libicuuc.${soname}; fi 
     else
        if [[ -L $1/libicudata.${soname}.48 || -e $1/libicudata.${soname}.48 ]]; then rm $1/libicudata.${soname}.48; fi 
        if [[ -L $1/libicuuc.${soname}.48 || -e $1/libicuuc.${soname}.48 ]]; then rm $1/libicuuc.${soname}.48; fi 
        if [[ -L $1/libicudata.${soname} || -e $1/libicudata.${soname} ]]; then rm $1/libicudata.${soname}; fi 
        if [[ -L $1/libicuuc.${soname} || -e $1/libicuuc.${soname} ]]; then rm $1/libicuuc.${soname}; fi 
     fi
 fi      

 echo "Creating symbolic links for the ICU 48 libraries"
 if [ "$platform" = "AIX" ]
  then
     ln -s libicudata48.0.${soname} $1/libicudata48.${soname}
     ln -s libicuuc48.0.${soname} $1/libicuuc48.${soname}     
 else
     ln -s libicudata.${soname}.48.0 $1/libicudata.${soname}.48     
     ln -s libicuuc.${soname}.48.0 $1/libicuuc.${soname}.48
 fi

echo "Setting permissions for the libraries"
chmod 755 $1/libicu*
chmod 755 $1/libODP*
chmod 755 $1/libioq*
# There is no libIOQ* on RHEL RTL so we check if 
# the files exist before we attempt chmod on those.
ls $1/libIOQ* >/dev/null 2>&1
[ $? -eq 0 ] && chmod 755 $1/libIOQ*
echo "Done"
exit 0



